==> jc-1.4.0.tar.gz: jas/TableswitchInsn.h <==
// public class jas.TableswitchInsn

// class file dependencies
// @dep_class 4062a5c70c6293f0 jas_Insn
// @dep_class 18fca077ecc39346 jas_TableswitchInsn
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header jas_Insn

#include "jas/Insn.h"

#ifndef _JC_jas_TableswitchInsn_H_
#define _JC_jas_TableswitchInsn_H_

// Forward structure declarations
struct _jc_jas_Label$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_TableswitchInsn$sub_refs	_jc_jas_TableswitchInsn$sub_refs;
typedef struct _jc_jas_TableswitchInsn$sub_nonrefs	_jc_jas_TableswitchInsn$sub_nonrefs;
typedef struct _jc_jas_TableswitchInsn$refs	_jc_jas_TableswitchInsn$refs;
typedef struct _jc_jas_TableswitchInsn$nonrefs	_jc_jas_TableswitchInsn$nonrefs;
typedef struct _jc_jas_TableswitchInsn$object	_jc_jas_TableswitchInsn$object;

typedef const struct _jc_jas_TableswitchInsn$vmethods	_jc_jas_TableswitchInsn$vmethods;
typedef const struct _jc_jas_TableswitchInsn$vtable	_jc_jas_TableswitchInsn$vtable;
typedef const struct _jc_jas_TableswitchInsn$vtype	_jc_jas_TableswitchInsn$vtype;

// Constructors
extern void _jc_jas_TableswitchInsn$method$_init$5890551397616ed7(_jc_env *, struct _jc_jas_TableswitchInsn$object *, jint, jint, struct _jc_jas_Label$object *, struct _jc_object_array *);

// Virtual methods structure
struct _jc_jas_TableswitchInsn$vmethods {
};

// Vtable
struct _jc_jas_TableswitchInsn$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_Insn$vmethods	jas_Insn;
	_jc_jas_TableswitchInsn$vmethods	jas_TableswitchInsn;
};

// Vtype
struct _jc_jas_TableswitchInsn$vtype {
	_jc_type			type;
	_jc_jas_TableswitchInsn$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_TableswitchInsn$sub_refs {
};

// Reference instance fields (object)
struct _jc_jas_TableswitchInsn$refs {
    _jc_jas_TableswitchInsn$sub_refs	jas_TableswitchInsn;
    _jc_jas_Insn$sub_refs	jas_Insn;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_TableswitchInsn$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_TableswitchInsn$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_Insn$sub_nonrefs	jas_Insn;
    _jc_jas_TableswitchInsn$sub_nonrefs	jas_TableswitchInsn;
};

// Object instance structure
struct _jc_jas_TableswitchInsn$object {
	_jc_jas_TableswitchInsn$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_TableswitchInsn$vtype	*vtype;
	_jc_jas_TableswitchInsn$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_TableswitchInsn$vtype _jc_jas_TableswitchInsn$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_TableswitchInsn, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_TableswitchInsn$class_object;

#endif	/* _JC_jas_TableswitchInsn_H_ */

==> jc-1.4.6.tar.gz: jas/TableswitchInsn.h <==
// public class jas.TableswitchInsn

// class file dependencies
// @dep_class 4062a5c70c6293f0 jas_Insn
// @dep_class 18fca077ecc39346 jas_TableswitchInsn
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header jas_Insn

#include "jas/Insn.h"

#ifndef _JC_jas_TableswitchInsn_H_
#define _JC_jas_TableswitchInsn_H_

// Forward structure declarations
struct _jc_jas_Label$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_TableswitchInsn$sub_refs	_jc_jas_TableswitchInsn$sub_refs;
typedef struct _jc_jas_TableswitchInsn$sub_nonrefs	_jc_jas_TableswitchInsn$sub_nonrefs;
typedef struct _jc_jas_TableswitchInsn$refs	_jc_jas_TableswitchInsn$refs;
typedef struct _jc_jas_TableswitchInsn$nonrefs	_jc_jas_TableswitchInsn$nonrefs;
typedef struct _jc_jas_TableswitchInsn$object	_jc_jas_TableswitchInsn$object;

typedef const struct _jc_jas_TableswitchInsn$vmethods	_jc_jas_TableswitchInsn$vmethods;
typedef const struct _jc_jas_TableswitchInsn$vtable	_jc_jas_TableswitchInsn$vtable;
typedef const struct _jc_jas_TableswitchInsn$vtype	_jc_jas_TableswitchInsn$vtype;

// Constructors
extern void _jc_jas_TableswitchInsn$method$_init$5890551397616ed7(_jc_env *, struct _jc_jas_TableswitchInsn$object *, jint, jint, struct _jc_jas_Label$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_jas_TableswitchInsn$vmethods {
};

// Vtable
struct _jc_jas_TableswitchInsn$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_Insn$vmethods	jas_Insn;
	_jc_jas_TableswitchInsn$vmethods	jas_TableswitchInsn;
};

// Vtype
struct _jc_jas_TableswitchInsn$vtype {
	_jc_type			type;
	_jc_jas_TableswitchInsn$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_TableswitchInsn$sub_refs {
};

// Reference instance fields (object)
struct _jc_jas_TableswitchInsn$refs {
    _jc_jas_TableswitchInsn$sub_refs	jas_TableswitchInsn;
    _jc_jas_Insn$sub_refs	jas_Insn;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_TableswitchInsn$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_TableswitchInsn$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_Insn$sub_nonrefs	jas_Insn;
    _jc_jas_TableswitchInsn$sub_nonrefs	jas_TableswitchInsn;
};

// Object instance structure
struct _jc_jas_TableswitchInsn$object {
	_jc_jas_TableswitchInsn$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_TableswitchInsn$vtype	*vtype;
	_jc_jas_TableswitchInsn$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_TableswitchInsn$vtype _jc_jas_TableswitchInsn$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_TableswitchInsn, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_TableswitchInsn$class_object;

#endif	/* _JC_jas_TableswitchInsn_H_ */
